@@ -14,6 +14,9 @@
 # Keith Herbert, Virginia Commonwealth University
 # herbertkb at vcu.edu
 #
+# Alexander D. McQuilkin, Virginia Commonwealth University 
+# alexmcq99 at yahoo.com
+#
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
@@ -170,7 +173,7 @@ my $pkg = "UMLS::Association";
 
 use vars qw($VERSION);
 
-$VERSION = '0.07';
+$VERSION = '0.09';
 
 my $debug = 0;
 
@@ -182,7 +185,6 @@ my $debug = 0;
 #  input : $params <- reference to hash containing the parameters 
 #  output:
 sub new {
-
     my $self      = {};
     my $className = shift;
     my $params    = shift;
@@ -258,6 +260,8 @@ sub _checkOptions {
     my $port         = $params->{'port'};
     my $username     = $params->{'username'};
     my $password     = $params->{'password'};
+    my $getDescendants = $params->{'getdescendants'};
+    my $umls = $params->{'umls'};
    
     #  cuifinder options
     my $measure = $params->{'config'}; 
@@ -275,7 +279,12 @@ sub _checkOptions {
 	my $str = "The --username option must be defined when using --password.";
 	$errorhandler->_error($pkg, $function, $str, 10);
     }
-
+    
+    if((defined $getDescendants) && (!defined $umls))
+    {
+	my $str = "There must be a UMLS Interface object for getDescendants to be used.";
+	$errorhandler->_error($pkg, $function, $str, 10);
+    }
 }
 
 =head3 exists
